==> system-api-1.0.3-20250306.075918-2-sources.jar: com/elitescloud/cloudt/xyc/dto/ZbzzSysPageFieldConfigDtlQueryDTO.java <==
package com.elitescloud.cloudt.xyc.dto;

import com.elitescloud.cloudt.common.annotation.SysCode;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
@Data
public class ZbzzSysPageFieldConfigDtlQueryDTO  implements Serializable {
    private static final long serialVersionUID = 7292586233258774067L;
    private Long id;

    /** 所属应用 */
    @ApiModelProperty(name = "所属应用",notes = "")
    private String appCode ;
    /** 所属应用名称 */
    @ApiModelProperty(name = "所属应用名称",notes = "")
    private String appName ;
    /** 配置名称 */
    @ApiModelProperty(name = "配置名称",notes = "")
    private String configName ;
    /** 配置编码 */
    @ApiModelProperty(name = "配置编码",notes = "")
    private String configCode ;
    /** 字段名称 */
    @ApiModelProperty(name = "字段名称",notes = "")
    private String fieldName ;
    /** 字段编码 */
    @ApiModelProperty(name = "字段编码",notes = "")
    private String fieldCode ;
    /** 是否必填 */
    @ApiModelProperty(name = "是否必填",notes = "")
    private Boolean fieldRequired ;
    /** 字段别名 */
    @ApiModelProperty(name = "字段别名",notes = "")
    private String fieldAlias ;
    /** 行号 */
    @ApiModelProperty(name = "行号",notes = "")
    private Double linenum ;
    @ApiModelProperty(name = "字段类型", notes = "字段的数据类型，这可以用于根据数据类型执行不同的验证或格式化操作")
    private String fieldType;
    @ApiModelProperty(name = "字段类型名称", notes = "字段的数据类型，这可以用于根据数据类型执行不同的验证或格式化操作")
    private String fieldTypeName;
    @ApiModelProperty(name = "字段排序",notes = "字段在页面上的排序顺序")
    private Integer fieldOrder ;
    @ApiModelProperty(name = "是否隐藏",notes = "")
    private Boolean fieldHidden ;
    @ApiModelProperty(name = "是否可编辑",notes = "")
    private Boolean fieldEdit;
    @ApiModelProperty(name = "默认值展示",notes = "")
    private String fieldDefaultValue ;
    @ApiModelProperty(name = "字段宽度",notes = "")
    private String fieldWidth ;
    @ApiModelProperty(name = "字段帮助",notes = "字段的详细描述，以便在页面上提供更多的信息")
    private String fieldDescription;
    @ApiModelProperty(name = "字段样式", notes = "字段的样式属性")
    private String fieldStyle;

    //新增增加
    @ApiModelProperty("启用")
    private Boolean enabled;

    @SysCode(sys = "cloudt-system", mod = "DATA_TYPE")
    @ApiModelProperty("数据类型")
    private String dataType;
    private String dataTypeName;

    @SysCode(sys = "cloudt-system", mod = "PAGE_CONFIG_SOURCE_TYPE")
    @ApiModelProperty("来源类型")
    private String sourceType;
    private String sourceTypeName;

    @SysCode(sys = "cloudt-system", mod = "DISPLAY_STYLE")
    @ApiModelProperty("值显示风格")
    private String valueStyle;
    private String valueStyleName;

    @ApiModelProperty("udc-model")
    private String udcModel;

    @ApiModelProperty("udc-code")
    private String udcCode;

    @ApiModelProperty("udc-name")
    private String udcName;

    @ApiModelProperty("前端配置")
    private String frontConfig;

    @ApiModelProperty("主表ID")
    private Long masId;

    @ApiModelProperty("关联组件字段")
    private String relateObjField;

    @ApiModelProperty("关联组件名称字段")
    private String relateObjNameField;
}

==> system-api-1.0.3-20250312.044647-3-sources.jar: com/elitescloud/cloudt/xyc/dto/ZbzzSysPageFieldConfigDtlQueryDTO.java <==
package com.elitescloud.cloudt.xyc.dto;

import com.elitescloud.cloudt.common.annotation.SysCode;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
@Data
public class ZbzzSysPageFieldConfigDtlQueryDTO  implements Serializable {
    private static final long serialVersionUID = 7292586233258774067L;
    private Long id;

    /** 所属应用 */
    @ApiModelProperty(name = "所属应用",notes = "")
    private String appCode ;
    /** 所属应用名称 */
    @ApiModelProperty(name = "所属应用名称",notes = "")
    private String appName ;
    /** 配置名称 */
    @ApiModelProperty(name = "配置名称",notes = "")
    private String configName ;
    /** 配置编码 */
    @ApiModelProperty(name = "配置编码",notes = "")
    private String configCode ;
    /** 字段名称 */
    @ApiModelProperty(name = "字段名称",notes = "")
    private String fieldName ;
    /** 字段编码 */
    @ApiModelProperty(name = "字段编码",notes = "")
    private String fieldCode ;
    /** 是否必填 */
    @ApiModelProperty(name = "是否必填",notes = "")
    private Boolean fieldRequired ;
    /** 字段别名 */
    @ApiModelProperty(name = "字段别名",notes = "")
    private String fieldAlias ;
    /** 行号 */
    @ApiModelProperty(name = "行号",notes = "")
    private Double linenum ;
    @ApiModelProperty(name = "字段类型", notes = "字段的数据类型，这可以用于根据数据类型执行不同的验证或格式化操作")
    private String fieldType;
    @ApiModelProperty(name = "字段类型名称", notes = "字段的数据类型，这可以用于根据数据类型执行不同的验证或格式化操作")
    private String fieldTypeName;
    @ApiModelProperty(name = "字段排序",notes = "字段在页面上的排序顺序")
    private Integer fieldOrder ;
    @ApiModelProperty(name = "是否隐藏",notes = "")
    private Boolean fieldHidden ;
    @ApiModelProperty(name = "是否可编辑",notes = "")
    private Boolean fieldEdit;
    @ApiModelProperty(name = "默认值展示",notes = "")
    private String fieldDefaultValue ;
    @ApiModelProperty(name = "字段宽度",notes = "")
    private String fieldWidth ;
    @ApiModelProperty(name = "字段帮助",notes = "字段的详细描述，以便在页面上提供更多的信息")
    private String fieldDescription;
    @ApiModelProperty(name = "字段样式", notes = "字段的样式属性")
    private String fieldStyle;

    //新增增加
    @ApiModelProperty("启用")
    private Boolean enabled;

    @SysCode(sys = "cloudt-system", mod = "DATA_TYPE")
    @ApiModelProperty("数据类型")
    private String dataType;
    private String dataTypeName;

    @SysCode(sys = "cloudt-system", mod = "PAGE_CONFIG_SOURCE_TYPE")
    @ApiModelProperty("来源类型")
    private String sourceType;
    private String sourceTypeName;

    @SysCode(sys = "cloudt-system", mod = "DISPLAY_STYLE")
    @ApiModelProperty("值显示风格")
    private String valueStyle;
    private String valueStyleName;

    @ApiModelProperty("udc-model")
    private String udcModel;

    @ApiModelProperty("udc-code")
    private String udcCode;

    @ApiModelProperty("udc-name")
    private String udcName;

    @ApiModelProperty("前端配置")
    private String frontConfig;

    @ApiModelProperty("主表ID")
    private Long masId;

    @ApiModelProperty("关联组件字段")
    private String relateObjField;

    @ApiModelProperty("关联组件名称字段")
    private String relateObjNameField;

    @ApiModelProperty(name = "是否后端字段，0：不是，1：是",notes = "")
    private Boolean backendFlag ;

    @ApiModelProperty(name = "是否导入、导出字段，0：不是，1：是",notes = "")
    private Boolean iportEportFlag ;
}
